@@ -14,8 +14,7 @@ var cgmap = function($)
     /* initalise all maps after page has been loaded and the dom tree
      * is fully intstantiated
      */
-    $(document).ready( function() {
-
+    $(window).bind("load", function() {
         // set images path
         if (cgmap.imgpath) {OpenLayers.ImgPath = cgmap.imgpath;}
 
@@ -37,6 +36,31 @@ var cgmap = function($)
                     cgmap.config[evt.data].map.events.clearMouseCache();
                 });
             }
+	    /* Provide a fix to presenting OpenLayers maps that are 
+	     * on hidden form panels, such as tabs, by invoking layer
+	     * redraw functionality when our map comes into view. Once this
+	     * redraw has taken place, we unbind our click method.
+	     */
+	    var fieldset = $(map).parents('.formPanel:hidden');
+	    if (fieldset.length === 1) {
+	        var legend_id = fieldset[0].id.replace(/fieldset-/g, "a#fieldsetlegend-");
+		$(legend_id).parent().click(function (evt) {
+ 		    var ol_map = cgmap.config[mapid].map;
+		    // Make base layer tiles load correctly.
+		    ol_map.baseLayer.onMapResize();
+		    ol_map.baseLayer.redraw();
+		    ol_map.updateSize();
+		    /* Zoom to correctly re-position the map. Having layers
+		     * loaded whilst the map was hidden cause positioning
+		     * issues, and this solves them.
+		     */
+		    var feature_layer = ol_map.getLayersByClass('OpenLayers.Layer.Vector');
+		    if (feature_layer.length === 1) {
+		        ol_map.zoomToExtent(feature_layer[0].getDataExtent());
+		    }
+		    $(this).unbind(evt);
+		}); 
+	    }
         });
     });
 
@@ -462,7 +486,9 @@ OpenLayers.Control.WKTEditingToolbar = OpenLayers.Class(
                 new OpenLayers.Control.DrawFeature(layer, OpenLayers.Handler.Point, {'displayClass': 'olControlDrawFeaturePoint'}),
                 new OpenLayers.Control.DrawFeature(layer, OpenLayers.Handler.Path, {'displayClass': 'olControlDrawFeaturePath'}),
                 new OpenLayers.Control.DrawFeature(layer, OpenLayers.Handler.Polygon, {'displayClass': 'olControlDrawFeaturePolygon'}),
-                new OpenLayers.Control.ModifyFeature(layer)
+                new OpenLayers.Control.ModifyFeature(layer, {
+                    mode: OpenLayers.Control.ModifyFeature.RESHAPE | OpenLayers.Control.ModifyFeature.DRAG
+                })
             ];
             this.addControls(controls);
 
@@ -480,6 +506,7 @@ OpenLayers.Control.WKTEditingToolbar = OpenLayers.Class(
                 if (feat)
                 {
                     layer.addFeatures([feat]);
+		    layer.map.zoomToExtent(layer.getDataExtent());
                 }
             }
 
@@ -504,4 +531,4 @@ OpenLayers.Control.WKTEditingToolbar = OpenLayers.Class(
         CLASS_NAME: 'OpenLayers.Control.EditingToolbar'
 
     }
-);
\ No newline at end of file
+);
