@@ -1,4 +1,5 @@
-from Products.Five import zcml
+# from Products.Five import zcml
+from Zope2.App import zcml
 from Products.Five import fiveconfigure
 
 from Products.PloneTestCase import PloneTestCase as ptc
